package Bundle::Bio::Phylo::PhyLoTA;

$VERSION = '0.2';

1;

__END__

=head1 NAME

Bundle::Bio::Phylo::PhyLoTA - Modules used in supersmart-phylota project

=head1 SYNOPSIS

perl -MCPAN -e 'install Bundle::Bio::Phylo::PhyLoTA'

=head1 CONTENTS

DBIx::Class
Getopt::Long
Pod::Usage
Bio::Phylo
Template
Config::Tiny
DBI
DBD::mysql
Moose
Bio::Species
XML::Twig

=head1 DESCRIPTION

Modules used in supersmart-phylota project.